# imma

[![Build Status](https://travis-ci.org/mjirik/imma.svg?branch=master)](https://travis-ci.org/mjirik/imma)
[![Coverage Status](https://coveralls.io/repos/github/mjirik/imma/badge.svg?branch=master)](https://coveralls.io/github/mjirik/imma?branch=master)


Image manipulation package
